/*
 * Composite sync generation
 * Device: EP610
 */

active_low input
	hsync, vsync, csync_mode;
active_high input
	vidclk;

active_low output clocked_by (vidclk)
	hs, vs;
active_high output clocked_by (vidclk)
	count[0:5], cs;
active_low output
	max;

/* hs & vs get delayed one vidclk cycle */
hs := hsync;
vs := vsync;

/* Generate cs with or without serrations, according to csync_mode */
cs := if csync_mode then hsync | vsync		/* no serrations */
	else ~hsync & (vsync | ~max) endif;	/* serrations */
	/* With serrations, cs is asserted after the trailing edge of hsync,
	   until max is true (indicating count==0) or during vsync. */

/* `count' counts up while hsync & ~max, down while ~hsync & ~max */
function carry(f[0:5]) = hsync & (count == f) | ~hsync & (~count == f);

count[0] := count[0] ^ ~max & carry(<%%%%%%>);
count[1] := count[1] ^ ~max & carry(<1%%%%%>);
count[2] := count[2] ^ ~max & carry(<11%%%%>);
count[3] := count[3] ^ ~max & carry(<111%%%>);
count[4] := count[4] ^ ~max & carry(<1111%%>);
count[5] := count[5] ^ ~max & carry(<11111%>);

/* max is asserted when count reaches the limit in either direction */
max = carry(<111111>);
